@@ -1014,7 +1014,13 @@ class Project(object):
                         # new workflow
                         for oKey, iKey in matches:
                             childPointer = getattr(newChildProt, iKey)
-                            if isinstance(childPointer, pwobj.PointerList):
+
+                            # Scalar with pointer case: If is a scalar with a pointer
+                            if isinstance(childPointer, pwobj.Scalar) and childPointer.hasPointer():
+                              # In this case childPointer becomes the contained Pointer
+                              childPointer = childPointer.getPointer()
+
+                            elif isinstance(childPointer, pwobj.PointerList):
                                 for p in childPointer:
                                     if p.getObjValue().getObjId() == prot.getObjId():
                                         childPointer = p
@@ -1129,6 +1135,7 @@ class Project(object):
                 prot._useQueue.set(protDict.get('_useQueue', False))
                 prot._queueParams.set(protDict.get('_queueParams', None))
                 prot._prerequisites.set(protDict.get('_prerequisites', None))
+                prot.forceSchedule.set(protDict.get('forceSchedule', False))
                 newDict[protId] = prot
                 self.saveProtocol(prot)
 
@@ -1136,11 +1143,13 @@ class Project(object):
         def _setPointer(pointer, value):
             # Properly setup the pointer value checking if the 
             # id is already present in the dictionary
-            parts = value.split('.')
-            target = newDict.get(parts[0], None)
-            pointer.set(target)
-            if not pointer.pointsNone():
-                pointer.setExtendedParts(parts[1:])
+            # Value to pointers could be None: Partial workflows
+            if value:
+                parts = value.split('.')
+                target = newDict.get(parts[0], None)
+                pointer.set(target)
+                if not pointer.pointsNone():
+                    pointer.setExtendedParts(parts[1:])
 
         def _setPrerequisites(prot):
             prerequisites = prot.getPrerequisites()
@@ -1177,9 +1186,17 @@ class Project(object):
                                 p = pwobj.Pointer()
                                 _setPointer(p, value)
                                 attr.append(p)
-                        # For "normal" parameters we just set the string value 
+                        # For "normal" parameters we just set the string value
                         else:
-                            attr.set(protDict[paramName])
+                            try:
+                                attr.set(protDict[paramName])
+                            # Case for Scalars with pointers. So far this will work for Numbers. With Strings (still there are no current examples)
+                            # We will need something different to test if the value look like a pointer: regex? ####.text
+                            except ValueError as e:
+                                newPointer = pwobj.Pointer()
+                                _setPointer(newPointer, protDict[paramName])
+                                attr.setPointer(newPointer)
+
                 self.mapper.store(prot)
 
         f.close()
