@@ -331,6 +331,12 @@ class Form(object):
     def addParallelSection(self, threads=1, mpi=8, condition="",
                            hours=72, jobsize=0):
 
+        """ Adds the parallelization section to the form
+            pass threads=0 to disable threads parameter and mpi=0 to disable mpi params
+
+        :param threads: default value for of threads, defaults to 1
+        :param mpi: default value for mpi, defaults to 8"""
+
         self.addSection(label='Parallelization')
         self.addParam('hostName', StringParam, default="localhost",
                       label='Execution host',
@@ -449,11 +455,22 @@ class PointerParam(Param):
         self.allowsNull = Boolean(args.get('allowsNull', False))
         
     def setPointerClass(self, newPointerClass):
-        if ',' in newPointerClass:
+
+        # Tolerate passing classes instead of their names
+        if isinstance(newPointerClass, list):
             self.pointerClass = CsvList()
-            self.pointerClass.set(newPointerClass)
+            self.pointerClass.set(",". join([clazz.__name__ for clazz in newPointerClass]))
+
+        elif(isinstance(newPointerClass, str)):
+            if ',' in newPointerClass:
+                self.pointerClass = CsvList()
+                self.pointerClass.set(newPointerClass)
+            else:
+                self.pointerClass = String(newPointerClass)
+
+        # Single class item, not the string
         else:
-            self.pointerClass = String(newPointerClass)
+            self.pointerClass = String(newPointerClass.__name__)
 
 
 class MultiPointerParam(PointerParam):
